SystemOrganization addCategory: #'System-Announcements'!

Announcer subclass: #SystemAnnouncer
	instanceVariableNames: 'suspended'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

SystemAnnouncer class
	instanceVariableNames: 'announcer privateAnnouncer'!

!SystemAnnouncer commentStamp: '<historical>' prior: 0!
This class plays the role of the announcer for events raised by the Pharo system.

Currently, it acts as a wrapper over the SystemChangeNotifier, but in the future it should be used for announcing the events directly from the system.. 

BEWARE: You should not need to subclass me. Think about just using me to send your announces (if you need system behavior) or using your own announcers as instance or class  variables.!

SystemAnnouncer class
	instanceVariableNames: 'announcer privateAnnouncer'!

!SystemAnnouncer class methodsFor: 'private' stamp: 'EstebanLorenzano 7/27/2012 19:39'!
announceFromEvent: aChangeEvent
	"This method creates an announcement from a given Event (subclass of AbstractEvent) and announces it.
	
	For example, from an AddedEvent that concerns a class the method creates SystemAddedClassAnnouncement and then it will announce it both from the generic announcer and from the classAnnouncer "
	| announcement |
	
	announcement := aChangeEvent asSystemAnnouncement.
	self uniqueInstance announce: announcement.! !

!SystemAnnouncer class methodsFor: 'accessing' stamp: 'EstebanLorenzano 7/27/2012 12:25'!
announcer
	"Answer a system annoncer."
	^ self uniqueInstance! !

!SystemAnnouncer class methodsFor: 'accessing' stamp: 'GuillermoPolito 4/27/2012 13:25'!
announcer: anAnnouncer
	announcer := anAnnouncer! !

!SystemAnnouncer class methodsFor: 'instance creation' stamp: 'EstebanLorenzano 7/27/2012 14:55'!
current
	"Answer a system annoncer."
	self flag: #todo. "Remove Me"
	^ self uniqueInstance! !

!SystemAnnouncer class methodsFor: 'utilities' stamp: 'EstebanLorenzano 7/27/2012 11:16'!
defaultPreferredAnnouncementClassForEvent: aChangeEvent

	| itemKindName eventKindName announcementClassName announcementClass |
	self flag: #todo. "Remove?"
	itemKindName := aChangeEvent itemKind.
	eventKindName := (aChangeEvent class name endsWith: 'Event') 
		ifTrue: [ aChangeEvent class name copyFrom: 1 to: aChangeEvent class name size - 'Event' size ] 
		ifFalse: [ aChangeEvent class name ].
	announcementClassName := 	(
										'System', 
										itemKindName capitalized, 
										eventKindName,
										'Announcement'
									) asSymbol.
	announcementClass := Smalltalk at: announcementClassName ifAbsent: [nil].
	^ announcementClass! !

!SystemAnnouncer class methodsFor: 'initialization' stamp: 'EstebanLorenzano 7/27/2012 18:53'!
initialize
	"self initialize"
	
	"SystemAnnouncer uniqueInstance 
		notify: self ofAllSystemChangesUsing: #announceFromEvent:"! !

!SystemAnnouncer class methodsFor: 'accessing' stamp: 'EstebanLorenzano 7/27/2012 19:43'!
privateAnnouncer
	"Answer a system annoncer. Normally you should not invoke it"

	^privateAnnouncer ifNil: [ privateAnnouncer := self new ]! !

!SystemAnnouncer class methodsFor: 'accessing' stamp: 'StephaneDucasse 6/2/2012 22:07'!
privateAnnouncer: anAnnouncer
	"Answer a system annoncer."

	privateAnnouncer := anAnnouncer! !

!SystemAnnouncer class methodsFor: 'utilities' stamp: 'EstebanLorenzano 7/27/2012 19:44'!
reset
	announcer := nil.
	privateAnnouncer := nil.	! !

!SystemAnnouncer class methodsFor: 'utilities' stamp: 'GuillermoPolito 7/31/2012 12:11'!
restoreAllNotifications
	"self restoreAllNotifications"
	
	| collector |
	self reset.
	collector := PragmaCollector filter: [ :pragma | pragma keyword = #systemEventRegistration ].
	collector reset.
	collector do: [ :pragma |
		pragma methodClass theNonMetaClass perform: pragma selector.
	]! !

!SystemAnnouncer class methodsFor: 'instance creation' stamp: 'EstebanLorenzano 7/27/2012 12:15'!
uniqueInstance
	"Answer a system annoncer."
	
	^ announcer ifNil: [ announcer := self new ]! !

!SystemAnnouncer class methodsFor: 'initialization' stamp: 'CamilleTeruel 7/29/2012 18:49'!
unload
	SystemAnnouncer uniqueInstance unsubscribe: self! !

!SystemAnnouncer class methodsFor: 'utilities' stamp: 'EstebanLorenzano 7/27/2012 12:18'!
unsubscribe: anObject
	"unsubscribe an object from my public/private announcers"
	self flag: #todo. "remove me"
	self uniqueInstance unsubscribe: anObject.
	self privateAnnouncer unsubscribe: anObject! !

!SystemAnnouncer methodsFor: 'announce' stamp: 'EstebanLorenzano 7/27/2012 19:50'!
announce: anAnnouncement
	self isSuspended 
		ifFalse: [ 
			self class privateAnnouncer basicAnnounce: anAnnouncement.
			self basicAnnounce: anAnnouncement ]! !

!SystemAnnouncer methodsFor: 'announce' stamp: 'EstebanLorenzano 7/27/2012 19:36'!
basicAnnounce: anAnnouncement
	super announce: anAnnouncement.! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/1/2012 23:56'!
class: aClass oldComment: oldComment newComment: newComment oldStamp: oldStamp newStamp: newStamp
	"A class was commented in the system."

	self announce: (ClassCommented class: aClass oldComment: oldComment newComment: newComment oldStamp: oldStamp newStamp: newStamp)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 10:14'!
class: aClass recategorizedFrom: oldCategory to: newCategory 
	self announce: (ClassRecategorized 
						class: aClass
						recategorizedFrom: oldCategory
						to: newCategory)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/1/2012 17:55'!
classAdded: aClass inCategory: aCategoryName 
	self announce: (ClassAdded class: aClass category: aCategoryName)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 00:23'!
classCategoryAdded: aClassCategoryName

	self announce: (CategoryAdded categoryName: aClassCategoryName)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 10:09'!
classCategoryRemoved: aClassCategoryName

	self announce: (CategoryRemoved categoryName: aClassCategoryName)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 00:06'!
classCategoryRenamedFrom: anOldClassCategoryName to: aNewClassCategoryName

	self announce: (CategoryRenamed
					classCategoryRenamedFrom: anOldClassCategoryName 
					to: aNewClassCategoryName)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/1/2012 23:56'!
classCommented: aClass
	"A class with the given name was commented in the system."

	self announce: (ClassCommented classCommented: aClass)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 00:16'!
classDefinitionChangedFrom: oldClass to: newClass
	self announce: (ClassModifiedClassDefinition classDefinitionChangedFrom: oldClass to: newClass)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 00:30'!
classRemoved: aClass fromCategory: aCategoryName 
	self announce: (ClassRemoved class: aClass category: aCategoryName)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 00:34'!
classRenamed: aClass from: oldClassName to: newClassName inCategory: aCategoryName 
	self announce: (ClassRenamed 
				class: aClass
				category: aCategoryName
				oldName: oldClassName
				newName: newClassName)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 00:37'!
classReorganized: aClass
	self announce: (ClassReorganized class: aClass)! !

!SystemAnnouncer methodsFor: 'temporal for remove' stamp: 'EstebanLorenzano 7/27/2012 15:42'!
doSilently: aBlock
	self suspendAllWhile: aBlock! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'EstebanLorenzano 7/27/2012 15:39'!
evaluated: textOrStream
	^ self evaluated: textOrStream context: nil.! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 00:43'!
evaluated: expression context: aContext
	self announce: (ExpressionEvaluated 
				expression: expression
				context: aContext)! !

!SystemAnnouncer methodsFor: 'announce' stamp: 'EstebanLorenzano 7/27/2012 11:04'!
isSuspended
	^suspended ifNil: [ suspended := false ]! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'EstebanLorenzano 7/27/2012 15:39'!
methodAdded: aMethod

	^ self methodAdded: aMethod selector: aMethod selector inClass: aMethod methodClass ! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/1/2012 18:14'!
methodAdded: aMethod selector: aSymbol inClass: aClass 
	"A method with the given selector was added to aClass, but not put in a protocol."

	self announce: (MethodAdded
				method: aMethod 
				selector: aSymbol
				class: aClass)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/1/2012 18:14'!
methodAdded: aMethod selector: aSymbol inClass: aClass requestor: requestor
	"A method with the given selector was added to aClass, but not put in a protocol."

	self announce: (MethodAdded
				method: aMethod 
				selector: aSymbol
				protocol: nil
				class: aClass
				requestor: requestor)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/1/2012 18:14'!
methodAdded: aMethod selector: aSymbol inProtocol: aCategoryName class: aClass 
	"A method with the given selector was added to aClass in protocol aCategoryName."

	self announce: (MethodAdded
				method: aMethod
				selector: aSymbol
				protocol: aCategoryName
				class: aClass)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/1/2012 18:13'!
methodAdded: aMethod selector: aSymbol inProtocol: aCategoryName class: aClass requestor: requestor
	"A method with the given selector was added to aClass in protocol aCategoryName."

	self announce: (MethodAdded
				method: aMethod
				selector: aSymbol
				protocol: aCategoryName
				class: aClass
				requestor: requestor)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'CamilleTeruel 7/29/2012 18:51'!
methodChangedFrom: oldMethod to: newMethod 

	self methodChangedFrom: oldMethod 
		to: newMethod 
		selector: newMethod selector 
		inClass: newMethod methodClass 
		oldProtocol: nil 
		newProtocol: nil 
		requestor: nil! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'EstebanLorenzano 7/27/2012 15:39'!
methodChangedFrom: oldMethod to: newMethod selector: newSelector inClass: aClass

	self methodChangedFrom: oldMethod to: newMethod selector: newSelector inClass: aClass oldProtocol: nil newProtocol: nil requestor: nil! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 09:55'!
methodChangedFrom: oldMethod to: newMethod selector: aSymbol inClass: aClass oldProtocol: oldProtocol newProtocol: newProtocol requestor: requestor
	self announce: (MethodModified
					methodChangedFrom: oldMethod
					to: newMethod
					selector: aSymbol 
					inClass: aClass
					oldProtocol: oldProtocol
					newProtocol: newProtocol
					requestor: requestor)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'EstebanLorenzano 7/27/2012 15:39'!
methodChangedFrom: oldMethod to: newMethod selector: aSymbol inClass: aClass requestor: requestor

	self methodChangedFrom: oldMethod to: newMethod selector: aSymbol inClass: aClass oldProtocol: nil newProtocol: nil requestor: requestor! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'EstebanLorenzano 7/27/2012 15:39'!
methodRemoved: aMethod 
	^ self methodRemoved: aMethod selector: aMethod selector class: aMethod methodClass! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 00:52'!
methodRemoved: aMethod selector: aSymbol class: aClass 
	"A method with the given selector was removed from the class."

	self announce: (MethodRemoved
						methodRemoved: aMethod 
						selector: aSymbol
						protocol: nil
						class: aClass)! !

!SystemAnnouncer methodsFor: 'announcements-convenience' stamp: 'GuillermoPolito 8/2/2012 00:52'!
methodRemoved: aMethod selector: aSymbol inProtocol: protocol class: aClass 
	"A method with the given selector was removed from the class."

	self announce: (MethodRemoved
						methodRemoved: aMethod 
						selector: aSymbol
						protocol: protocol
						class: aClass)! !

!SystemAnnouncer methodsFor: 'system triggers' stamp: 'GuillermoPolito 8/2/2012 10:00'!
selector: selector recategorizedFrom: oldCategory to: newCategory inClass: aClass

	self announce: (MethodRecategorized 
				method: (aClass compiledMethodAt: selector ifAbsent: [nil])
				selector: selector
				class: aClass
				newProtocol: newCategory
				oldProtocol: oldCategory)! !

!SystemAnnouncer methodsFor: 'announce' stamp: 'EstebanLorenzano 7/27/2012 11:06'!
suspendAllWhile: aBlock
	| oldSuspended |
	oldSuspended := self isSuspended.
	suspended := true.
	aBlock ensure: [ suspended := oldSuspended ]! !

!SystemAnnouncer methodsFor: 'system triggers' stamp: 'CamilleTeruel 7/29/2012 18:44'!
traitDefinitionChangedFrom: oldTrait to: newTrait
	self announce: (ModifiedTraitDefinitionEvent traitDefinitionChangedFrom: oldTrait to: newTrait)! !

!SystemAnnouncer methodsFor: 'temporal for remove' stamp: 'CamilleTeruel 7/30/2012 10:21'!
trigger: announcement 
	^ self announce: announcement.! !

!ReorganizedEvent methodsFor: '*System-Announcements' stamp: 'StephaneDucasse 7/15/2010 23:19'!
category

	^self itemCategory! !

!ModifiedMethodEvent methodsFor: '*System-Announcements' stamp: 'HenrikSperreJohansen 1/13/2012 14:29'!
asSystemAnnouncement
	^ MethodModified new event: self! !

!AbstractEvent methodsFor: '*System-Announcements' stamp: 'EstebanLorenzano 7/27/2012 15:38'!
asAnnouncement 
	^self asSystemAnnouncement! !

!AbstractEvent methodsFor: '*System-Announcements' stamp: 'CamilleTeruel 7/29/2012 18:40'!
asSystemAnnouncement
	| itemKindName eventKindName announcementClassName announcementClass |
	itemKindName := self itemKind.
	eventKindName := (self class name endsWith: 'Event') 
		ifTrue: [ self class name copyFrom: 1 to: self class name size - 'Event' size ] 
		ifFalse: [ self class name ].
	announcementClassName := (itemKindName capitalized, eventKindName) asSymbol.
	announcementClass := Smalltalk at: announcementClassName ifAbsent: [nil].
	^ announcementClass isNil 
		ifTrue: [ UnknownSystemChange new ]
		ifFalse: [announcementClass new event: self]! !

!DoItEvent methodsFor: '*System-Announcements' stamp: 'EstebanLorenzano 7/27/2012 14:20'!
asSystemAnnouncement
	^ ExpressionEvaluated new 
		event: self;
		yourself! !

Object subclass: #AnnouncementLogger
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!AnnouncementLogger commentStamp: 'StephaneDucasse 5/9/2011 17:17' prior: 0!
Use me to debug and log to the transcript annoncements.


AnnouncementLogger new subscribeTo: SystemAnnouncer announcer

To unsubscribe

AnnouncementLogger  allInstancesDo: [:each | SystemAnnouncer announcer unsubscribe: each ]!

!AnnouncementLogger methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 5/9/2011 17:11'!
logAnnouncement: ann

	Transcript show: ann printString ; cr! !

!AnnouncementLogger methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 5/9/2011 17:15'!
subscribeTo: anAnnouncer

	anAnnouncer "weak" 
		on: Announcement send: #logAnnouncement: to: self! !

Announcement subclass: #SystemAnnouncement
	instanceVariableNames: 'event timeStamp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!SystemAnnouncement commentStamp: '<historical>' prior: 0!
The root announcement for the events coming from the Pharo system.

Currently, it wraps the event that comes from the SystemChangeNotifier.!

SystemAnnouncement subclass: #CategoryAdded
	instanceVariableNames: 'categoryName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!CategoryAdded commentStamp: 'cyrilledelaunay 1/18/2011 12:29' prior: 0!
This announcement will be emited when adding a category using:
=> SystemOrganizer >> addCategory:!

!CategoryAdded class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/1/2012 17:57'!
categoryName: aCategoryName
	^self new
			categoryName: aCategoryName;
			yourself! !

!CategoryAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 17:58'!
categoryName

	^ categoryName! !

!CategoryAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 17:56'!
categoryName: aCategoryName
	categoryName := aCategoryName! !

!CategoryAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 17:58'!
item
	^self categoryName! !

SystemAnnouncement subclass: #CategoryRemoved
	instanceVariableNames: 'categoryName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!CategoryRemoved commentStamp: 'cyrilledelaunay 1/18/2011 12:28' prior: 0!
This announcement will be emited when removing a category using:
=> SystemOrganizer >> removeCategory:!

!CategoryRemoved class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 00:02'!
categoryName: aCategoryName
	^self new
			categoryName: aCategoryName;
			yourself! !

!CategoryRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:03'!
categoryName
	^categoryName! !

!CategoryRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:02'!
categoryName: aCategoryName
	categoryName := aCategoryName! !

!CategoryRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:03'!
categorySelector
	^self categoryName asSymbol! !

!CategoryRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:11'!
item
	^self categoryName! !

SystemAnnouncement subclass: #CategoryRenamed
	instanceVariableNames: 'from to newCategoryName oldCategoryName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!CategoryRenamed commentStamp: 'cyrilledelaunay 1/18/2011 12:26' prior: 0!
This announcement will be emited when renaming a category using:
=> SystemOrganizer >> renameCategory:toBe:!

!CategoryRenamed class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 00:05'!
classCategoryRenamedFrom: anOldCategoryName to: aNewCategoryName
	^self new
			newCategoryName: aNewCategoryName;
			oldCategoryName: anOldCategoryName;
			yourself! !

!CategoryRenamed methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:12'!
item
	^self newCategoryName! !

!CategoryRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:05'!
newCategoryName
	^newCategoryName! !

!CategoryRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:05'!
newCategoryName: aCategoryName
	newCategoryName := aCategoryName! !

!CategoryRenamed methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:06'!
newName
	^self newCategoryName! !

!CategoryRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:05'!
oldCategoryName
	^oldCategoryName! !

!CategoryRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:05'!
oldCategoryName: aCategoryName
	oldCategoryName := aCategoryName! !

!CategoryRenamed methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:06'!
oldName
	^self oldCategoryName! !

!CategoryRenamed methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:06'!
oldNameSymbol
	^self oldCategoryName asSymbol! !

SystemAnnouncement subclass: #ClassAdded
	instanceVariableNames: 'classAdded classCategory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!ClassAdded commentStamp: 'cyrilledelaunay 1/18/2011 11:56' prior: 0!
This announcement will be emitted when a class or a trait is added, using:
	=> Trait >> named: (the notification is done in Trait >> named:uses:category:env:)
	=> Class >> subclass:
	!

!ClassAdded class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/1/2012 17:52'!
class: aClass category: aClassCategoryName
	^self new
			classAdded: aClass;
			classCategory: aClassCategoryName;
			yourself! !

!ClassAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 17:46'!
classAdded
	^classAdded! !

!ClassAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 17:47'!
classAdded: aClass
	classAdded := aClass! !

!ClassAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 17:51'!
classCategory
	^classCategory! !

!ClassAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 17:51'!
classCategory: aClassCategoryName
	classCategory := aClassCategoryName! !

!ClassAdded methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:12'!
item
	^self classAdded! !

!ClassAdded methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/1/2012 17:51'!
itemCategory
	^self classCategory! !

!ClassAdded methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/1/2012 17:47'!
itemClass
	^self classAdded! !

!ClassAdded methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/1/2012 17:47'!
itemClassSymbol

	^ self classAdded theNonMetaClass name asSymbol! !

SystemAnnouncement subclass: #ClassCommented
	instanceVariableNames: 'newStamp newComment classCommented oldComment oldStamp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!ClassCommented commentStamp: '<historical>' prior: 0!
This announcement will be emitted when a class or a trait comment changes!

!ClassCommented class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/1/2012 23:51'!
class: aClass oldComment: oldComment newComment: newComment oldStamp: oldStamp newStamp: newStamp
	^self new
			classCommented: aClass;
			oldComment: oldComment;
			oldStamp: oldStamp;
			newComment: newComment;
			newStamp: newStamp;
			yourself! !

!ClassCommented class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/1/2012 23:53'!
classCommented: aClass
	self flag: #fixMePlease. "nils? no way!! "
	^self class: aClass oldComment: nil newComment: nil oldStamp: nil newStamp: nil! !

!ClassCommented methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:13'!
classCommented
	^classCommented! !

!ClassCommented methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:55'!
classCommented: aClass
	classCommented := aClass! !

!ClassCommented methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:13'!
item
	^self classCommented! !

!ClassCommented methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:13'!
newComment
	^newComment! !

!ClassCommented methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:55'!
newComment: aNewComment
	newComment := aNewComment! !

!ClassCommented methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:13'!
newStamp
	^newStamp! !

!ClassCommented methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:54'!
newStamp: aNewStamp
	newStamp := aNewStamp! !

!ClassCommented methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:13'!
oldComment
	oldComment! !

!ClassCommented methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:55'!
oldComment: andOldComment
	oldComment := andOldComment! !

!ClassCommented methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:14'!
oldStamp
	oldStamp! !

!ClassCommented methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:55'!
oldStamp: anOldStamp
	oldStamp := anOldStamp! !

SystemAnnouncement subclass: #ClassModifiedClassDefinition
	instanceVariableNames: 'newClassDefinition oldClassDefinition'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!ClassModifiedClassDefinition commentStamp: '<historical>' prior: 0!
This announcement will be emitted when a class or a trait definition changes: when an inst var or a classVariable is added!

!ClassModifiedClassDefinition class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 00:09'!
classDefinitionChangedFrom: oldClass to: newClass
	^self new
			oldClassDefinition: oldClass;
			newClassDefinition: newClass;
			yourself! !

!ClassModifiedClassDefinition methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:11'!
anyChanges
	self flag: 'We should get rid of this please. normally if you send a changed event, is because something changed, so this is nonsense'.
"	^ self event isSuperclassModified
		| self event areInstVarsModified
			| self event areClassVarsModified
				| self event areSharedPoolsModified
					| self event isTraitCompositionModified."
	^true! !

!ClassModifiedClassDefinition methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:11'!
item
	^self newClassDefinition! !

!ClassModifiedClassDefinition methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:10'!
newClassDefinition
	^newClassDefinition! !

!ClassModifiedClassDefinition methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:09'!
newClassDefinition: aClass
	newClassDefinition := aClass! !

!ClassModifiedClassDefinition methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:10'!
oldClassDefinition
	^oldClassDefinition! !

!ClassModifiedClassDefinition methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:10'!
oldClassDefinition: aClass
	oldClassDefinition := aClass! !

!ClassModifiedClassDefinition methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:10'!
oldItem
	^self oldClassDefinition! !

SystemAnnouncement subclass: #ClassRecategorized
	instanceVariableNames: 'newCategory oldCategory classRecategorized'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!ClassRecategorized commentStamp: 'cyrilledelaunay 1/18/2011 10:42' prior: 0!
This announcement will be raised when:
- we set a category to a class (see 'Class >>category:')
- we set a category to a Trait (see Trait>>category:)

It corresponds to the RecategorizedEvent!

!ClassRecategorized class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/1/2012 23:58'!
class: aClass recategorizedFrom: oldCategory to: newCategory
	^self new
			classRecategorized: aClass;
			oldCategory: oldCategory;
			newCategory: newCategory;
			yourself! !

!ClassRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:59'!
classRecategorized
	^classRecategorized! !

!ClassRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:59'!
classRecategorized: aClass
	classRecategorized := aClass! !

!ClassRecategorized methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:15'!
item
	^self classRecategorized! !

!ClassRecategorized methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:25'!
itemCategory
	^self newCategory! !

!ClassRecategorized methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:00'!
itemClass 
	^self classRecategorized! !

!ClassRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:25'!
newCategory 
	^newCategory! !

!ClassRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:58'!
newCategory: aNewCategory
	newCategory := aNewCategory! !

!ClassRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:25'!
oldCategory
	^oldCategory! !

!ClassRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:58'!
oldCategory: anOldCategory
	oldCategory := anOldCategory! !

SystemAnnouncement subclass: #ClassRemoved
	instanceVariableNames: 'categoryName classRemoved'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!ClassRemoved commentStamp: 'cyrilledelaunay 1/18/2011 11:43' prior: 0!
the annoucement will be emitted when removing a class or a trait using:  
	=> removeFromSystem!

!ClassRemoved class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 00:29'!
class: aClass category: aCategoryName
	^self new
			classRemoved: aClass;
			categoryName: aCategoryName;
			yourself.! !

!ClassRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:29'!
categoryName
	
	^ categoryName! !

!ClassRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:29'!
categoryName: anObject
	
	categoryName := anObject! !

!ClassRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:29'!
classRemoved
	
	^ classRemoved! !

!ClassRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:29'!
classRemoved: anObject
	
	classRemoved := anObject! !

!ClassRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:30'!
item
	^self removedClass! !

!ClassRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 7/22/2012 16:09'!
itemClass
	"to make polymorphic the events"
	^self removedClass! !

!ClassRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:30'!
removedClass
	^self classRemoved! !

!ClassRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:30'!
removedClassCategory
	^self categoryName! !

SystemAnnouncement subclass: #ClassRenamed
	instanceVariableNames: 'category classRenamed newName oldName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!ClassRenamed commentStamp: 'cyrilledelaunay 1/18/2011 11:44' prior: 0!
the annoucement will be emitted when renaming a class or a trait using:  
	=> RenameClassRefactoring >> rename:to:
	=> class>>rename:
The corresponding event is raised in: SystemDictionary>>renameClass:from:to:!

!ClassRenamed class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 00:33'!
class: aClass category: aCategoryName oldName: anOldClassName newName: aNewClassName
	^self new
			classRenamed: aClass;
			category: aCategoryName;
			oldName: anOldClassName;
			newName: aNewClassName;
			yourself! !

!ClassRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:33'!
category
	
	^ category! !

!ClassRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:33'!
category: anObject
	
	category := anObject! !

!ClassRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:33'!
classRenamed
	
	^ classRenamed! !

!ClassRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:33'!
classRenamed: anObject
	
	classRenamed := anObject! !

!ClassRenamed methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:34'!
item
	^self classRenamed! !

!ClassRenamed methodsFor: 'temporal for remove' stamp: 'StephaneDucasse 10/12/2011 15:16'!
itemClass

	^ self item! !

!ClassRenamed methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:34'!
itemPackageName
	^self category! !

!ClassRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:33'!
newName
	^newName! !

!ClassRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:33'!
newName: anObject
	
	newName := anObject! !

!ClassRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:33'!
oldName
	^oldName! !

!ClassRenamed methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:33'!
oldName: anObject
	
	oldName := anObject! !

SystemAnnouncement subclass: #ClassReorganized
	instanceVariableNames: 'classReorganized'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!ClassReorganized commentStamp: 'cyrilledelaunay 1/18/2011 15:03' prior: 0!
This announcement corresponds to the ReorganizedEvent, which seems to (by looking at the references of ReorganizedEvent) be raised when:
- we rename a protocol (see 'renameCategory:toBe: '). if The category is not empty, SystemMethodRecategorizedAnnouncement will also be emitted
- we sort (modify the order of) protocols (see 'sortCategories')
- we add a protocol (see 'addCategory:before:')
- we remove a protocol (see 'removeCategory:' 'removeEmptyCategories')!

!ClassReorganized class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 00:36'!
class: aClass
	^self new
			classReorganized: aClass;
			yourself! !

!ClassReorganized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:36'!
classReorganized
	
	^ classReorganized! !

!ClassReorganized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:36'!
classReorganized: anObject
	
	classReorganized := anObject! !

!ClassReorganized methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:36'!
item
	^self classReorganized! !

!ClassReorganized methodsFor: 'temporal for remove' stamp: 'StephaneDucasse 10/12/2011 15:16'!
itemClass

	^ self item! !

SystemAnnouncement subclass: #ExpressionEvaluated
	instanceVariableNames: 'context expressionEvaluated'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!ExpressionEvaluated commentStamp: '<historical>' prior: 0!
This announcement correspond to code evaluation.  For example, a DoIt or PrintIt evaluated in a workspace raises one of this announcements.!

!ExpressionEvaluated class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 00:41'!
expression: theEvaluatedExpression
	^self expression: theEvaluatedExpression context: nil! !

!ExpressionEvaluated class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 00:42'!
expression: theEvaluatedExpression context: anExecutionContext
	^self new
			expressionEvaluated: theEvaluatedExpression;
			context: anExecutionContext;
			yourself! !

!ExpressionEvaluated methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:42'!
context
	
	^ context! !

!ExpressionEvaluated methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:42'!
context: anObject
	
	context := anObject! !

!ExpressionEvaluated methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:42'!
expression
	^self expressionEvaluated! !

!ExpressionEvaluated methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:42'!
expressionEvaluated
	
	^ expressionEvaluated! !

!ExpressionEvaluated methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:42'!
expressionEvaluated: anObject
	
	expressionEvaluated := anObject! !

!ExpressionEvaluated methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:50'!
item
	^expressionEvaluated! !

SystemAnnouncement subclass: #MethodAdded
	instanceVariableNames: 'method methodClass protocol selector'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!MethodAdded commentStamp: 'cyrilledelaunay 1/18/2011 13:06' prior: 0!
This announcement is emited when we add a method to a class or a trait using:
	=> Behavior >> compile: or TraitBehavior >> compile:!

!MethodAdded class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/1/2012 18:08'!
method: aCompiledMethod selector: aSelector class: aClass
	self flag: #look.  "Is it ok to send an event with no protocol?"
	^self
		method: aCompiledMethod
		selector: aSelector
		protocol: nil
		class: aClass
		requestor: nil! !

!MethodAdded class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/1/2012 18:22'!
method: aCompiledMethod selector: aSelector protocol: aProtocolName class: aClass
	self flag: #look.  "Is it ok to send an event with no requestor?"
	^self
		method: aCompiledMethod
		selector: aSelector
		protocol: aProtocolName
		class: aClass
		requestor: nil! !

!MethodAdded class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/1/2012 18:23'!
method: aCompiledMethod selector: aSelector protocol: aProtocolName class: aClass requestor: aRequestor
	^self new
			method: aCompiledMethod;
			selector: aSelector;
			protocol: aProtocolName;
			methodClass: aClass;
			yourself! !

!MethodAdded methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/1/2012 23:39'!
item
	^self method! !

!MethodAdded methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/1/2012 18:14'!
itemClass

	^self methodClass! !

!MethodAdded methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/1/2012 18:15'!
itemMethod

	^self method! !

!MethodAdded methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/1/2012 18:15'!
itemProtocol

	^self protocol! !

!MethodAdded methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/1/2012 18:18'!
itemRequestor
	self flag: #'we should probably remove this method'.
	self error: 'You should not use the requestor.  It will be removes'! !

!MethodAdded methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/1/2012 18:15'!
itemSelector

	^self selector! !

!MethodAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 18:12'!
method
	
	^ method! !

!MethodAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 18:10'!
method: aCompiledMethod
	method := aCompiledMethod! !

!MethodAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 18:12'!
methodClass
	
	^ methodClass! !

!MethodAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:38'!
methodClass: aClass
	methodClass := aClass! !

!MethodAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 18:12'!
protocol
	
	^ protocol! !

!MethodAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:38'!
protocol: aProtocolName
	protocol := aProtocolName! !

!MethodAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 18:12'!
selector
	
	^ selector! !

!MethodAdded methodsFor: 'accessing' stamp: 'GuillermoPolito 8/1/2012 23:38'!
selector: aSelector
	selector := aSelector! !

SystemAnnouncement subclass: #MethodModified
	instanceVariableNames: 'methodClass newMethod newProtocol oldMethod oldProtocol selector'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!MethodModified commentStamp: 'BenjaminVanRyseghem 4/1/2011 16:04' prior: 0!
This announcement is emited when we RE-compile a method in a class or a trait, with: ClassDescription >> compile: or TraitDescription >> compile:. If the method is not yet registered in the class or the trait, the announcement will not be emitted.

The action of renaming a method will be handled by SystemMethodRemovedAnnouncement and SystemMethodAddedAnnouncement, since this refactoring is concretely composed by removing the old method and add a new with the new name  !

!MethodModified class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 09:45'!
methodChangedFrom: oldMethod to: newMethod selector: selector inClass: aClass oldProtocol: oldProtocol newProtocol: newProtocol requestor: aRequestor
	^self new
			oldMethod: oldMethod;
			newMethod: newMethod;
			selector: selector;
			methodClass: aClass;
			oldProtocol: oldProtocol;
			newProtocol: newProtocol;
			yourself! !

!MethodModified class methodsFor: 'termporal for removal' stamp: 'CamilleTeruel 7/29/2012 19:01'!
oldMethod: oldMethod newMethod: newMethod
	(oldMethod class == newMethod class) 
		ifFalse: [ self error: 'The two methods don''t belong to the same class' ].
	(oldMethod selector == newMethod selector)
		ifFalse: [ self error: 'The two methods haven''t the same selector' ].
	^ self new
		oldMethod: oldMethod;
		newMethod: newMethod;
		yourself.! !

!MethodModified methodsFor: 'temp to remove' stamp: 'GuillermoPolito 8/2/2012 09:48'!
item
	^ self newMethod! !

!MethodModified methodsFor: 'temp to remove' stamp: 'GuillermoPolito 8/2/2012 09:48'!
itemClass

	^ self methodClass! !

!MethodModified methodsFor: 'temp to remove' stamp: 'GuillermoPolito 8/2/2012 09:48'!
itemProtocol

	^ self newProtocol! !

!MethodModified methodsFor: 'temp to remove' stamp: 'CamilleTeruel 7/29/2012 19:14'!
itemSelector

	^ self selector.
	! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:47'!
methodClass
	
	^ methodClass! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:47'!
methodClass: anObject
	
	methodClass := anObject! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:55'!
newMethod

	^ newMethod! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:55'!
newMethod: aCompiledMethod
	newMethod := aCompiledMethod.! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:47'!
newProtocol
	
	^ newProtocol! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:47'!
newProtocol: anObject
	
	newProtocol := anObject! !

!MethodModified methodsFor: 'temp to remove' stamp: 'GuillermoPolito 8/2/2012 09:49'!
oldItem
	"that is stupid..."
	^ self oldMethod! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:52'!
oldMethod
	^ oldMethod! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:55'!
oldMethod: aCompiledMethod
	oldMethod := aCompiledMethod.! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:47'!
oldProtocol
	
	^ oldProtocol! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:47'!
oldProtocol: anObject
	
	oldProtocol := anObject! !

!MethodModified methodsFor: 'accessing' stamp: 'CamilleTeruel 7/30/2012 14:10'!
selector
	^ newMethod.! !

!MethodModified methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:47'!
selector: anObject
	
	selector := anObject! !

SystemAnnouncement subclass: #MethodRecategorized
	instanceVariableNames: 'methodClass methodRecategorized newProtocol oldProtocol selector'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!MethodRecategorized commentStamp: 'cyrilledelaunay 1/18/2011 15:03' prior: 0!
This announcement will be emitted when:
	=> a non-empty protocol is renamed in a class or a trait (using ClassOrganizer >> renameCategory:toBe:). If the protocol does not contain any method, the announcement will not be emitted. Therefore, if we rename a non-empty protocol, both SystemMethodRecategorizedAnnouncement and SystemClassReorganizedAnnouncement will be emitted
	=> a method is removed from a category of a class or a trait (using ClassOrganizer >> removeElement:)
	=> a method is RE-categorized in a protocol of a trait or a class, using Organizer>>classify:under:.  If the method is classify under its current protocol, the announcement will not be emitted!

!MethodRecategorized class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 09:59'!
method: aCompiledMethod selector: aSelector class: aClass newProtocol: aNewProtocol oldProtocol: anOldProtocol

	^self new
			methodRecategorized: aCompiledMethod;
			selector: aSelector;
			methodClass: aClass;
			newProtocol: aNewProtocol;
			oldProtocol: anOldProtocol;
			yourself! !

!MethodRecategorized methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 10:11'!
item
	^self methodRecategorized! !

!MethodRecategorized methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 09:59'!
itemClass

	^self methodClass! !

!MethodRecategorized methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 09:59'!
itemNewProtocol

	^self newProtocol! !

!MethodRecategorized methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 09:59'!
itemOldProtocol

	^self oldProtocol! !

!MethodRecategorized methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 09:59'!
itemSelector

	^self selector! !

!MethodRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:57'!
methodClass
	
	^ methodClass! !

!MethodRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:57'!
methodClass: anObject
	
	methodClass := anObject! !

!MethodRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:57'!
methodRecategorized
	
	^ methodRecategorized! !

!MethodRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:57'!
methodRecategorized: anObject
	
	methodRecategorized := anObject! !

!MethodRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:57'!
newProtocol
	
	^ newProtocol! !

!MethodRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:57'!
newProtocol: anObject
	
	newProtocol := anObject! !

!MethodRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:57'!
oldProtocol
	
	^ oldProtocol! !

!MethodRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:57'!
oldProtocol: anObject
	
	oldProtocol := anObject! !

!MethodRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:57'!
selector
	
	^ selector! !

!MethodRecategorized methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 09:57'!
selector: anObject
	
	selector := anObject! !

SystemAnnouncement subclass: #MethodRemoved
	instanceVariableNames: 'methodRemoved protocol selector methodClass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!MethodRemoved commentStamp: 'cyrilledelaunay 1/18/2011 14:43' prior: 0!
This announcement will be emitted when a method is removed from a trait or a class, 
using ClassDescription >>removeSelector: or TraitDescription >> removeSelector.
!

!MethodRemoved class methodsFor: 'instance creation' stamp: 'GuillermoPolito 8/2/2012 00:49'!
methodRemoved: aCompiledMethod selector: aSelector protocol: aProtocol class: aClass
	^self new
			methodRemoved: aCompiledMethod;
			selector: aSelector;
			protocol: aProtocol;
			methodClass: aClass;
			yourself! !

!MethodRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:49'!
item

	^ self methodRemoved
	! !

!MethodRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:49'!
itemClass

	^ self methodClass! !

!MethodRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:49'!
itemMethod

	^ self methodRemoved
	! !

!MethodRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:49'!
itemProtocol

	^ self protocol! !

!MethodRemoved methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 00:49'!
itemSelector

	^self selector! !

!MethodRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:49'!
methodClass
	
	^methodClass! !

!MethodRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:48'!
methodClass: anObject
	
	methodClass := anObject! !

!MethodRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:48'!
methodRemoved
	
	^ methodRemoved! !

!MethodRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:48'!
methodRemoved: anObject
	
	methodRemoved := anObject! !

!MethodRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:48'!
protocol
	
	^ protocol! !

!MethodRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:48'!
protocol: anObject
	
	protocol := anObject! !

!MethodRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:49'!
selector
	^selector! !

!MethodRemoved methodsFor: 'accessing' stamp: 'GuillermoPolito 8/2/2012 00:48'!
selector: anObject
	
	selector := anObject! !

SystemAnnouncement subclass: #ProtocolAdded
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!ProtocolAdded commentStamp: '<historical>' prior: 0!
This class is not used, but should be used when we hook into the addition and removal of protocols. Right now, we only get ClassReorganizedAnnouncement!

SystemAnnouncement subclass: #ProtocolRemoved
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!

!ProtocolRemoved commentStamp: '<historical>' prior: 0!
This class is not used, but should be used when we hook into the addition and removal of protocols. Right now, we only get ClassReorganizedAnnouncement!

!SystemAnnouncement class methodsFor: 'instance creation' stamp: 'StephaneDucasse 4/13/2011 17:03'!
fromInternal: anInternalAnnouncement
	"create a new announcement from an internal announcement. Copy the variables"
	
	| instance |
	self flag: #ben. "why copy does not work?"
	instance := self new.
	1 to: self allInstVarNames size do:[:i | instance instVarAt: i put: ( anInternalAnnouncement instVarAt: i )].
	^ instance! !

!SystemAnnouncement class methodsFor: 'instance creation' stamp: 'StephaneDucasse 8/9/2011 23:05'!
new 
	
	^ super new setTimeStamp; yourself! !

!SystemAnnouncement methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 10:24'!
event
	^ self! !

!SystemAnnouncement methodsFor: 'temporal for remove' stamp: 'tg 6/5/2010 12:17'!
event: anObject
	event := anObject! !

!SystemAnnouncement methodsFor: 'temporal for remove' stamp: 'GuillermoPolito 8/2/2012 10:24'!
item

	^ self subclassResponsibility! !

!SystemAnnouncement methodsFor: 'private' stamp: 'StephaneDucasse 8/9/2011 23:05'!
setTimeStamp

	timeStamp := TimeStamp current.! !

!SystemAnnouncement methodsFor: 'accessing' stamp: 'StephaneDucasse 8/9/2011 23:04'!
timeStamp

	^ timeStamp! !

!SystemAnnouncement methodsFor: 'accessing' stamp: 'StephaneDucasse 8/9/2011 23:04'!
timeStamp: aTimeStamp

	timeStamp := aTimeStamp! !

SystemAnnouncement subclass: #UnknownSystemChange
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Announcements'!
SystemAnnouncer initialize!
